@@ -274,7 +274,14 @@ void VariantList::addVariantsFromAlignment(const vector<string> & seqs, const Re
 			
 			if ( referenceList.getReferenceCount() )
 			{
-				varNew->reference = referenceList.getReference(sequence).sequence[position];
+				if ( offset > 0 )
+				{
+					varNew->reference = '-';
+				}
+				else
+				{
+					varNew->reference = referenceList.getReference(sequence).sequence[position];
+				}
 			}
 			else
 			{
@@ -973,16 +980,24 @@ void VariantList::writeToProtocolBuffer(Harvest * msg) const
 	}
 }
 
-void VariantList::writeToVcf(std::ostream &out, bool indels, const ReferenceList & referenceList, const TrackList & trackList) const
+void VariantList::writeToVcf(std::ostream &out, bool indels, const ReferenceList & referenceList, const AnnotationList & annotationList, const TrackList & trackList, const vector<int> & tracksFocus, bool signature) const
 {
 	//tjt: Currently outputs SNPs, no indels
 	//tjt: next pass will add standard VCF output for indels, plus an attempt at qual vals
 	//tjt: also filters need to be added to findVariants to populate FILTer column
-
+	
+	int annCur = -1; // current annotation
+	int annNext = 0;
+	
 	//indel char, to skip columns with indels (for now)
 	char indl = '-';
 	//the VCF output file
 
+	out << "##INFO=<ID=CDS,Number=1,Type=String,Description=\"Coding sequence locus\">" << endl;
+	out << "##INFO=<ID=SYN,Number=0,Type=Flag,Description=\"All alternative alleles are synonymous in coding sequence\">" << endl;
+	out << "##INFO=<ID=AAR,Number=1,Type=String,Description=\"Reference amino acid in coding sequence\">" << endl;
+	out << "##INFO=<ID=AAA,Number=.,Type=String,Description=\"Alternate amino acid in coding sequence, one per alternate allele\">" << endl;
+	
 	for ( int i = 0; i < filters.size(); i++ )
 	{
 		const Filter & filter = filters.at(i);
@@ -994,11 +1009,31 @@ void VariantList::writeToVcf(std::ostream &out, bool indels, const ReferenceList
 	//#CHROM  POS     ID      REF     ALT     QUAL    FILTER  INFO    FORMAT  AA1 
 	out << "#CHROM\tPOS\tID\tREF\tALT\tQUAL\tFILTER\tINFO\tFORMAT";
 
-
-	//output the file name for each column
-	for ( int i = 0; i < trackList.getTrackCount(); i++ )
+	vector<int> tracks;
+	
+	if ( signature )
 	{
-		const TrackList::Track & track = trackList.getTrack(i);
+		// output all tracks
+		
+		for ( int i = 0; i < trackList.getTrackCount(); i++ )
+		{
+			tracks.push_back(i);
+		}
+	}
+	else
+	{
+		// only output tracks of interest (will be all if not differential)
+		
+		for ( int i = 0; i < tracksFocus.size(); i++ )
+		{
+			tracks.push_back(tracksFocus[i]);
+		}
+	}
+	
+	//output the file name for each column
+	for ( int i = 0; i < tracks.size(); i++ )
+	{
+		const TrackList::Track & track = trackList.getTrack(tracks[i]);
 		//out << '\t' << (msgTrack.has_name() ? msgTrack.name() : msgTrack.file());
 		out << '\t' << track.file;
 	}
@@ -1010,16 +1045,96 @@ void VariantList::writeToVcf(std::ostream &out, bool indels, const ReferenceList
 	{
 		const Variant & variant = variants.at(j);
 
-		//no indels for now..
-		if (variant.alleles[0] == indl)
+		//no indels for now.. TODO: should this check outside the clade also?
+		bool indel = false;
+		//
+		for ( int i = 0; i < tracks.size(); i++ )
+		{
+			if ( variant.alleles[tracks[i]] == indl )
+			{
+				indel = true;
+				break;
+			}
+		}
+		
+		if ( indel )
+		{
 			continue;
+		}
+		
+		if ( tracks.size() != trackList.getTrackCount() )
+		{
+			// differential
 			
-		if (find(variant.alleles.begin(), variant.alleles.end(),indl) != variant.alleles.end())
-			continue;
-
+			bool same = true;
+			
+			for ( int i = 1; i < tracks.size(); i++ )
+			{
+				if ( variant.alleles[tracks[i]] != variant.alleles[tracks[0]] )
+				{
+					same = false;
+					break;
+				}
+			}
+			
+			if ( same )
+			{
+				continue;
+			}
+		}
+		else if ( signature )
+		{
+			bool pass[tracks.size()];
+			
+			for ( int i = 0; i < tracks.size(); i++ )
+			{
+				pass[i] = variant.alleles[i] != variant.alleles[tracksFocus[0]];
+			}
+			
+			for ( int i = 0; i < tracksFocus.size(); i++ )
+			{
+				pass[tracksFocus[i]] = variant.alleles[tracksFocus[i]] == variant.alleles[tracksFocus[0]];
+			}
+			
+			bool isSignature = true;
+			
+			for ( int i = 0; i < tracks.size(); i++ )
+			{
+				if ( ! pass[i] )
+				{
+					isSignature = false;
+					break;
+				}
+			}
+			
+			if ( ! isSignature )
+			{
+				continue;
+			}
+		}
+		
 		//capture the reference position of variant
 		int pos = variant.position;
-
+		
+		// annotations use concatenated coords; sum previous ref lengths to translate
+		//
+		int offset = 0;
+		//
+		for ( int i = 0; i < variant.sequence; i++ )
+		{
+			offset += referenceList.getReference(i).sequence.length();
+		}
+		
+		while ( annNext < annotationList.getAnnotationCount() && annotationList.getAnnotation(annNext).start <= pos + offset )
+		{
+			if ( annotationList.getAnnotation(annNext).feature == "CDS" )
+			{
+				annCur = annNext;
+			}
+			
+			annNext++;
+		}
+		
 		//output first few columns, including context (+/- 7bp for now)
 		int ws = 10;
 		int lend = pos-ws;
@@ -1042,20 +1157,22 @@ void VariantList::writeToVcf(std::ostream &out, bool indels, const ReferenceList
 		out << "\t" << variant.reference << "\t";
 		allele_list.push_back(variant.reference);
 		bool prev_var = false;
-		for ( int i = 0; i < trackList.getTrackCount(); i++ )
+		for ( int i = 0; i < tracks.size(); i++ )
 		{
-			if (find(allele_list.begin(), allele_list.end(), variant.alleles[i]) == allele_list.end())
+			char allele = variant.alleles[tracks[i]];
+			
+			if (find(allele_list.begin(), allele_list.end(), allele) == allele_list.end())
 			{
-				if (variant.alleles[i] == indl) 
-					continue;
+				if (allele == indl) 
+					continue; // should never happen
 					
 				//to know if we need to output a preceding comma
-				if (!prev_var)
-				out << variant.alleles[i];
-				else
-				out << "," << variant.alleles[i];
+				if (prev_var)
+					out << ",";
+				
+				out << allele;
 
-				allele_list.push_back(variant.alleles[i]);
+				allele_list.push_back(allele);
 				prev_var = true;
 			}
 		}
@@ -1098,7 +1215,52 @@ void VariantList::writeToVcf(std::ostream &out, bool indels, const ReferenceList
 		}
 		
 		//INFO
-		out << "\tNA";
+		//
+		out << '\t';
+		//
+		if ( annCur != -1 && annotationList.getAnnotation(annCur).end >= pos + offset )
+		{
+			out << "CDS=" << annotationList.getAnnotation(annCur).locus << ';';
+			
+			string codonRef = refseq.substr(annotationList.getAnnotation(annCur).start - offset + (pos + offset - annotationList.getAnnotation(annCur).start) / 3 * 3, 3);
+			int codonPos = (pos + offset - annotationList.getAnnotation(annCur).start) % 3;
+			
+			bool rc = annotationList.getAnnotation(annCur).reverse;
+			
+			string aaRef = translations.count(codonRef) ? rc ? translationsRc.at(codonRef) : translations.at(codonRef) : ".";
+			out << "AAR=" << aaRef << ";AAA=";
+			
+			bool syn = true;
+			
+			for ( int i = 1; i < allele_list.size(); i++ )
+			{
+				if ( i > 1 )
+				{
+					out << ',';
+				}
+				
+				string codonAlt = codonRef;
+				codonAlt[codonPos] = allele_list.at(i);
+				string aaAlt = translations.count(codonAlt) ? rc ? translationsRc.at(codonAlt) : translations.at(codonAlt) : ".";
+				
+				if ( aaRef != aaAlt )
+				{
+					syn = false;
+				}
+				
+				out << aaAlt;
+			}
+			
+			if ( syn )
+			{
+				out << ";SYN";
+			}
+		}
+		else
+		{
+			out << "NA";
+		}
+		
 		//FORMAT
 		out << "\tGT";
 
@@ -1112,9 +1274,9 @@ void VariantList::writeToVcf(std::ostream &out, bool indels, const ReferenceList
 			indexByAllele[allele_list[i]] = i;
 		}
 		
-		for (i = 0; i < trackList.getTrackCount(); i++ )
+		for (i = 0; i < tracks.size(); i++ )
 		{
-			out << "\t" << indexByAllele[variant.alleles[i]];
+			out << "\t" << indexByAllele[variant.alleles[tracks[i]]];
 		}
 		
 		out << "\n";
